@@ -8,10 +8,16 @@ FixStyle(dplr,FixDPLR)
 #define LMP_FIX_DPLR_H
 
 #include <stdio.h>
+#include <map>
 #include "fix.h"
-#include "pair_nnp.h"
+#include "pair_deepmd.h"
+#ifdef LMPPLUGIN
 #include "DeepTensor.h"
 #include "DataModifier.h"
+#else
+#include "deepmd/DeepTensor.h"
+#include "deepmd/DataModifier.h"
+#endif
 
 #ifdef HIGH_PREC
 #define FLOAT_PREC double
@@ -32,20 +38,25 @@ public:
     void post_force(int);
     int pack_reverse_comm(int, int, double *);
     void unpack_reverse_comm(int, int *, double *);
+    double compute_scalar(void);
+    double compute_vector(int);
 private:
-    PairNNP * pair_nnp;
-    DeepTensor dpt;
-    DataModifier dtm;
-    string model;
+    PairDeepMD * pair_deepmd;
+    deepmd::DeepTensor dpt;
+    deepmd::DipoleChargeModifier dtm;
+    std::string model;
     int ntypes;
-    vector<int > sel_type;
-    vector<int > dpl_type;
-    vector<int > bond_type;
-    map<int,int > type_asso;
-    map<int,int > bk_type_asso;
-    vector<FLOAT_PREC> dipole_recd;
-    vector<double> dfcorr_buff;
-    void get_valid_pairs(vector<pair<int,int> >& pairs);
+    std::vector<int > sel_type;
+    std::vector<int > dpl_type;
+    std::vector<int > bond_type;
+    std::map<int,int > type_asso;
+    std::map<int,int > bk_type_asso;
+    std::vector<FLOAT_PREC> dipole_recd;
+    std::vector<double> dfcorr_buff;
+    std::vector<double> efield;
+    std::vector<double> efield_fsum, efield_fsum_all;
+    int efield_force_flag;
+    void get_valid_pairs(std::vector<std::pair<int,int> >& pairs);
   };
 }
 
